@@ -1,4 +1,4 @@
-context("model-api")
+context("MIP: model-api")
 
 describe("nvars()", {
   it("returns the number of variables", {
@@ -23,6 +23,16 @@ describe("nvars()", {
   })
 })
 
+describe("nconstraints()", {
+  it("returns the number of rows (constraints) of a model", {
+    m <- MIPModel() %>%
+      add_variable(x[i], i = 1:5) %>%
+      add_constraint(x[i] <= 10, i = 1:5) %>%
+      add_constraint(x[i] >= 5, i = 1:5)
+    expect_equal(nconstraints(m), 10)
+  })
+})
+
 describe("objective_function()", {
   it("returns a list with a vector and a constant by default", {
     model <- MIPModel() %>%
